/*
 * Name: Ben Walding
 * Date: 1 January 1998
 * Mod: 
 *
 * Display the CD database to the screen.
 *
 * Protected by the GNU Public License v2.0  <distrib>/GPL.LICENSE
 */

#include "cdinfo.h"
#include "cdlabel.h"
#include <stdio.h>
#include <unistd.h>
#include <qwidget.h>
#include <qtooltip.h>
#include <qpainter.h>
#include <qlistbox.h>
#include "cdinfo.moc"
#include "database.h"

cdInfo::cdInfo(QWidget *parent, const char *name = 0):QWidget(parent,name) 
{
  label_title = new QLabel(this, "label_title");

  label_title->setText("Title: - ");
  label_title->show(); 
  QToolTip::add(label_title, "Title of currently selected album");



  label_artist = new QLabel(this, "label_artist");
  label_artist->setText("Artist: -");
  label_artist->show();
  QToolTip::add(label_artist, "Artist who performed selected album");

  label_time = new QLabel(this, "totaltime");
  label_time->setText("Total Time: -");
  label_time->show();
  QToolTip::add(label_time, "Total length of album in min:sec");


  tracklist =  new QListBox(this, "tracklist");
  tracklist->show();
  QToolTip::add(tracklist, "List of tracks for current album");

  return;
}

// Func: MyAlbumList::MyAlbumList
// Constructor doesn't have to do anything much, simply call the update function
MyAlbumList::MyAlbumList(QWidget *parent, const char *name) : QListBox(parent, name)
{
  update();
}

// Func: MyAlbumList::update
// clear the list box
// then print text into it.
void MyAlbumList::update(void) {
  char buf[1024];
  Album *album_ptr;
  
  clear();

  for (album_ptr = album_list; album_ptr; album_ptr = album_ptr->next) {
	sprintf(buf, "%-35s %-25s", album_ptr->title(), album_ptr->artist());
	insertItem(buf);
  }
  return;
}

void cdInfo::display_info(int value) 
{
  Album *album_ptr = getAlbumIndex(value);
  char s[1024];
  int index = 1;
  bool clear = FALSE;
  Track *track_ptr;

  albumIndex = value;

  /* This should not occur - it will during debugging */

  if (value == -1) {
	clear = TRUE;
  } else 
  if (!album_ptr) {
    perror("cdInfo::display_info");
    return;
  }

  sprintf(s, "Title: %s", clear ? "-" : album_ptr->title());
  label_title->setText(s);

  sprintf(s, "Artist: %s", clear ? "-" : album_ptr->artist());
  label_artist->setText(s);

  if (clear) 
	sprintf(s, "Total Time: -");
  else
	sprintf(s, "Total Time: %2d:%02d", album_ptr->min(), album_ptr->sec());
  label_time->setText(s);

  tracklist->clear();
  if (!clear) {
	for (track_ptr = album_ptr->tracks; track_ptr; track_ptr=track_ptr->next) {
	  char buf[1024];
	  
	  sprintf(buf, "%2d %-40s  %2d:%02d", index++, track_ptr->title(), 
			  track_ptr->min(), track_ptr->sec());
	  
	  tracklist->insertItem(buf, -1);
	}
  }
  return;
}


// The caller should have already set up borders for the info box
void cdInfo::resizeEvent(QResizeEvent *) 
{
  label_title->setGeometry(20, 10, width() - 50, 20);
  label_artist->setGeometry(20,40, width() - 50, 20);
  label_time->setGeometry(20, 70, width() - 50, 20);
  tracklist->setGeometry(0, 100, width(), height() - 10);
}




